==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/AdmissionregistrationV1beta1ServiceReferenceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AdmissionregistrationV1beta1ServiceReferenceFluentImpl<A extends AdmissionregistrationV1beta1ServiceReferenceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements AdmissionregistrationV1beta1ServiceReferenceFluent<A>{

    private String name;
    private String namespace;
    private String path;

    public AdmissionregistrationV1beta1ServiceReferenceFluentImpl(){
    }
    public AdmissionregistrationV1beta1ServiceReferenceFluentImpl(AdmissionregistrationV1beta1ServiceReference instance){
            this.withName(instance.getName());

            this.withNamespace(instance.getNamespace());

            this.withPath(instance.getPath());

    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public String getNamespace(){
            return this.namespace;
    }

    public A withNamespace(String namespace){
            this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace(){
            return this.namespace != null;
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AdmissionregistrationV1beta1ServiceReferenceFluentImpl that = (AdmissionregistrationV1beta1ServiceReferenceFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/AdmissionregistrationV1beta1ServiceReferenceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AdmissionregistrationV1beta1ServiceReferenceFluentImpl<A extends AdmissionregistrationV1beta1ServiceReferenceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements AdmissionregistrationV1beta1ServiceReferenceFluent<A>{

    private String name;
    private String namespace;
    private String path;

    public AdmissionregistrationV1beta1ServiceReferenceFluentImpl(){
    }
    public AdmissionregistrationV1beta1ServiceReferenceFluentImpl(AdmissionregistrationV1beta1ServiceReference instance){
            this.withName(instance.getName());

            this.withNamespace(instance.getNamespace());

            this.withPath(instance.getPath());

    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public String getNamespace(){
            return this.namespace;
    }

    public A withNamespace(String namespace){
            this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace(){
            return this.namespace != null;
    }

    public A withNewNamespace(String arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuilder arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuffer arg1){
            return (A)withNamespace(new String(arg1));
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public A withNewPath(String arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1){
            return (A)withPath(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AdmissionregistrationV1beta1ServiceReferenceFluentImpl that = (AdmissionregistrationV1beta1ServiceReferenceFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            return true;
    }




}
